@@ -107,32 +107,34 @@ class Normalize(object):
     """
     Normalizes the input
 
-    :param initialization mu: mean of the normalization
-    :param initialization std: standard deviation of the normalization
-    :param forward x: input tensor (N_1, N_2, N_3, ...)
+    :param type: the desired type of normalization (z, unit or minmax)
+    :param optional bits: number of bits used to represent a pixel value (only if type is unit)
+    :param optional mu: normalization mean (only if type is z)
+    :param optional sigma: normalization std (only if type is z)
     :return: output tensor (N_1, N_2, N_3, ...)
     """
 
-    def __init__(self, mu=0, std=1):
+    def __init__(self, type='unit', bits=8, mu=None, sigma=None):
+        self.type = type
+        self.bits = bits
         self.mu = mu
-        self.std = std
+        self.sigma = sigma
 
     def __call__(self, x):
-        return (x - self.mu) / self.std
-
-
-class NormalizeMinMax(object):
-    """
-    Normalizes the input
-
-    :param forward x: input tensor (N_1, N_2, N_3, ...)
-    :return: output tensor (N_1, N_2, N_3, ...)
-    """
-
-    def __call__(self, x):
-        m = torch.min(x)
-        M = torch.max(x)
-        return (x - m) / (M - m)
+        if self.type == 'minmax':
+            # apply minmax normalization
+            m = x.min()
+            M = x.max()
+            eps = 1e-5
+            return (x - m + eps) / (M - m + eps)
+        elif self.type == 'unit':
+            # apply unit normalization
+            return x / (2**self.bits)
+        else:
+            # apply z normalization
+            mu = torch.mean(x) if self.mu is None else self.mu
+            sigma = torch.std(x) if self.sigma is None else self.sigma
+            return (x - mu) / sigma
 
 
 class ContrastAdjust(object):
